Welcome to margarine's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Introduction <intro>

   margarine Tutorials <tutorial>

   margarine Functions <functions>
